<?php
/**
 * Payment Modul fur s-publicservices.de.
 *
 * @version   4.1.8
 * @author    Thorsten Marx <thorsten.marx@s-publicservices.de>
 * @copyright 2011-2016 S-Public Services GmbH
 * @link      http://www.s-publicservices.de
 * @link      http://www.xtc-modified.org
 * @license   http://opensource.org/licenses/gpl-2.0.php GNU Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */
define("__GIROCONNECT_PLUGIN_VERSION__", "4.1.8");
if (file_exists(DIR_FS_CATALOG . 'includes/classes/giroconnect/library/GiroCheckout_SDK/GiroCheckout_SDK.php')) {
  require_once DIR_FS_CATALOG . 'includes/classes/giroconnect/library/GiroCheckout_SDK/GiroCheckout_SDK.php';
}
else {
  require_once '../includes/classes/giroconnect/library/GiroCheckout_SDK/GiroCheckout_SDK.php';
}

/**
 * Main class for girocheckout plugin.
 *
 * @author S-Public Services GmbH
 * @package GiroCheckout
 * @copyright Copyright (c) 2014, S-Public Services GmbH
 */
class giroconnect_main
{

  var $code, $title, $description, $transaction_id, $language, $enabled, $tmpStatus;
  var $_gc_cartID = 'cart_GC_ID';
  var $shopVersion = "";

  /**
   * Constructor method.
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return void
   */
  function __construct() {
    $this->transaction_id = '';
  }

// end giroconnect_main()

  /**
   * Set the language code
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return void
   */
  function _setLang() {
    if (substr($_SESSION['language_code'], 0, 2) == 'de') {
      $this->language = 'de';
    }
    else {
      $this->language = 'en';
    }
  }

// end _setLang()

  /**
   * Set the payment method code
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return void
   */
  function _setCode($code = 'gc_giropay') {
    $this->code = $code;
    $this->module = $code;
  }

// end _setCode()

  /**
   * Check if constant is defined.
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return string
   */
  function constant($name) {
    return (defined($name)) ? constant($name) : NULL;
  }
  // end constant()

  /**
   * Javascript validation
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return boolean
   */
  function javascript_validation() {
    return false;
  }

// end javascript_validation()

  /**
   * Update the module status dynamically
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return void
   */
  function update_status() {
    global $order;

    $merchantId = trim(giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_MERCHANTID'));
    $projectId = trim(giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_PROJECTID'));
    $password = trim(giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_PASSWORD'));

    //Checks if the currency is EURO
    $currency = $_SESSION['currency'];

    if (($this->enabled == true) && ((int)giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_ZONE') > 0)) {
      $check_flag = false;
      $check_query = xtc_db_query("select zone_id from " . TABLE_ZONES_TO_GEO_ZONES . " where geo_zone_id = '" . xtc_db_input(giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_ZONE')) .
        "' and zone_country_id = '" . xtc_db_input($order->billing['country']['id']) . "' order by zone_id");
      while ($check = xtc_db_fetch_array($check_query)) {
        if ($check['zone_id'] < 1) {
          $check_flag = true;
          break;
        }
        elseif ($check['zone_id'] == $order->billing['zone_id']) {
          $check_flag = true;
          break;
        }
      }

      if ($check_flag == false) {
        $this->enabled = false;
      }
    }
    else {
      if (($this->enabled == true) && (empty($merchantId) || empty($projectId) || empty($password))) {
        $this->enabled = false;
      }
      else {
        if ($this->code != "gc_creditcard" && $currency != "EUR") {
          $this->enabled = false;
        }
      }
    }
  }

// end update_status()

  /**
   * Displays the payment description in checkout confirmation page
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return void
   */
  function confirmation() {
    $strConfirmation = array('title' => $this->description_checkout);

    return $strConfirmation;
  }

// end confirmation()

  /**
   * Delete the order
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return void
   */
  function _deleteOrder($order_id) {
    $check_query = xtc_db_query('select orders_id from ' . TABLE_ORDERS_STATUS_HISTORY . ' where orders_id = "' . xtc_db_input((int)$order_id) . '" limit 1');
    if (xtc_db_num_rows($check_query) < 1) {
      xtc_db_query('delete from ' . TABLE_ORDERS . ' where orders_id = "' . xtc_db_input((int)$order_id) . '"');
      xtc_db_query('delete from ' . TABLE_ORDERS_TOTAL . ' where orders_id = "' . xtc_db_input((int)$order_id) . '"');
      xtc_db_query('delete from ' . TABLE_ORDERS_STATUS_HISTORY . ' where orders_id = "' . xtc_db_input((int)$order_id) . '"');
      xtc_db_query('delete from ' . TABLE_ORDERS_PRODUCTS . ' where orders_id = "' . xtc_db_input((int)$order_id) . '"');
      xtc_db_query('delete from ' . TABLE_ORDERS_PRODUCTS_ATTRIBUTES . ' where orders_id = "' . xtc_db_input((int)$order_id) . '"');
      xtc_db_query('delete from ' . TABLE_ORDERS_PRODUCTS_DOWNLOAD . ' where orders_id = "' . xtc_db_input((int)$order_id) . '"');
    }

    unset($_SESSION[$this->_gc_cartID]);
  }

// end _deleteOrder()

  /**
   * Functions to execute before process the payment
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return boolean
   */
  function before_process() {
    global $order;

    $delete_order = ((constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_DELETE_ORDER') == 'True') ? true : false);

    if ($delete_order) {
      $check_query = xtc_db_query('select orders_id from ' . TABLE_ORDERS . ' where orders_id = "' . (int)$_SESSION['tmp_oID'] . '" limit 1');
      if (xtc_db_num_rows($check_query) > 0) {
        xtc_db_query('delete from ' . TABLE_ORDERS . ' where orders_id = "' . (int)$_SESSION['tmp_oID'] . '"');
        xtc_db_query('delete from ' . TABLE_ORDERS_TOTAL . ' where orders_id = "' . (int)$_SESSION['tmp_oID'] . '"');
        xtc_db_query('delete from ' . TABLE_ORDERS_STATUS_HISTORY . ' where orders_id = "' . (int)$_SESSION['tmp_oID'] . '"');
        xtc_db_query('delete from ' . TABLE_ORDERS_PRODUCTS . ' where orders_id = "' . (int)$_SESSION['tmp_oID'] . '"');
        xtc_db_query('delete from ' . TABLE_ORDERS_PRODUCTS_ATTRIBUTES . ' where orders_id = "' . (int)$_SESSION['tmp_oID'] . '"');
        xtc_db_query('delete from ' . TABLE_ORDERS_PRODUCTS_DOWNLOAD . ' where orders_id = "' . (int)$_SESSION['tmp_oID'] . '"');
      }
    }
    else {
      $newStatus = constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_ORDER_STATUS_ID_ERROR');
      xtc_db_query("update " . TABLE_ORDERS . " set orders_status = '" . xtc_db_input($newStatus) . "', last_modified = now() where orders_id = '" . xtc_db_input((int)$_SESSION['tmp_oID']) . "' AND payment_class = '" . xtc_db_input($this->code) . "'");
    }

    unset($_SESSION['tmp_oID']);
    $GLOBALS[$_SESSION['payment']]->tmpOrders = true;

    return true;
  }

// end before_process()

  /**
   * Functions to execute after process the payment
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return boolean
   */
  function after_process() {
    return false;
  }

//end after_process()

  /**
   * Get error message to display
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return array
   */
  function get_error() {
    global $_GET;
    $error = array(
      'title' => $this->title,
      'error' => utf8_decode(stripslashes(urldecode($_GET['error'])))
    );

    return $error;
  }

//end get_error()

  /**
   * Check if module is installed (Administration Tool)_
   * TABLES: configuration
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return int
   */
  function check() {
    if (!isset($this->_check)) {
      $check_query = xtc_db_query("select configuration_value from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_" . xtc_db_input(strtoupper($this->code)) . "_STATUS'");
      $this->_check = xtc_db_num_rows($check_query);
    }

    return $this->_check;
  }

// end check()

  /**
   * Install the module (Administration Tool)_
   * TABLES: configuration
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return void
   */
  function install() {
    // Update Configuration Key Length 64 is often too short
    xtc_db_query('ALTER TABLE ' . TABLE_CONFIGURATION . ' CHANGE configuration_key configuration_key VARCHAR( 255 ) NOT NULL');
    // Update Configuration field Length 255 is often too short
    //xtc_db_query('ALTER TABLE ' . TABLE_CONFIGURATION . ' CHANGE set_function set_function VARCHAR( 510 ) NOT NULL');

    $cancelled_status_id = '2';
    $check_query = xtc_db_query("select orders_status_id from " . TABLE_ORDERS_STATUS . " where orders_status_name = 'Canceled [Giroconnect]' limit 1");
    if (xtc_db_num_rows($check_query) < 1) {
      $status_query = xtc_db_query("select max(orders_status_id) as status_id from " . TABLE_ORDERS_STATUS);
      $status = xtc_db_fetch_array($status_query);
      $cancelled_status_id = $status['status_id'] + 1;
      $languages = xtc_get_languages();
      foreach ($languages as $lang) {
        xtc_db_query("insert into " . TABLE_ORDERS_STATUS . " (orders_status_id, language_id, orders_status_name) values ('" . xtc_db_input($cancelled_status_id) . "', '" . xtc_db_input($lang['id']) . "', 'Canceled [Giroconnect]')");
      }
    }
    else {
      $check = xtc_db_fetch_array($check_query);
      $cancelled_status_id = $check['orders_status_id'];
    }

    xtc_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_key, configuration_value, configuration_group_id, sort_order, set_function, date_added)" .
      "  values ('MODULE_PAYMENT_" . strtoupper($this->code) . "_STATUS', 'True', '6', '0', 'xtc_cfg_select_option(array(\'True\', \'False\'), ', now())");
    xtc_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_key, configuration_value, configuration_group_id, sort_order, date_added)" .
      "  values ('MODULE_PAYMENT_" . strtoupper($this->code) . "_SORT_ORDER', '0', '6', '0', now())");
    xtc_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_key, configuration_value, configuration_group_id, sort_order, date_added)" .
      "  values ('MODULE_PAYMENT_" . strtoupper($this->code) . "_MERCHANTID', '', '6', '10', now())");
    xtc_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_key, configuration_value, configuration_group_id, sort_order, date_added)" .
      "  values ('MODULE_PAYMENT_" . strtoupper($this->code) . "_PROJECTID', '', '6', '10', now())");
    xtc_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_key, configuration_value, configuration_group_id, sort_order, date_added)" .
      "  values ('MODULE_PAYMENT_" . strtoupper($this->code) . "_PASSWORD', '', '6', '10', now())");
    xtc_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_key, configuration_value, configuration_group_id, sort_order, use_function, set_function, date_added)" .
      "  values ('MODULE_PAYMENT_" . strtoupper($this->code) . "_ZONE', '0', '6', '20', 'xtc_get_zone_class_title', 'xtc_cfg_pull_down_zone_classes(', now())");
    xtc_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_key, configuration_value, configuration_group_id, sort_order, date_added)" .
      "  values ('MODULE_PAYMENT_" . strtoupper($this->code) . "_ALLOWED', 'DE', '6', '30', now())");
    xtc_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_key, configuration_value, configuration_group_id, sort_order, set_function, use_function, date_added)" .
      "  values ('MODULE_PAYMENT_" . strtoupper($this->code) . "_ORDER_STATUS_ID_ERROR', '" . xtc_db_input($cancelled_status_id) . "', '6', '40', 'xtc_cfg_pull_down_order_statuses(', 'xtc_get_order_status_name', now())");
    xtc_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_key, configuration_value, configuration_group_id, sort_order, set_function, use_function, date_added)" .
      "  values ('MODULE_PAYMENT_" . strtoupper($this->code) . "_ORDER_STATUS_ID_OK', '1', '6', '40', 'xtc_cfg_pull_down_order_statuses(', 'xtc_get_order_status_name', now())");
    xtc_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_key, configuration_value, configuration_group_id, sort_order, set_function, use_function, date_added)" .
      "  values ('MODULE_PAYMENT_" . strtoupper($this->code) . "_ORDER_STATUS_ID_TEMP', '2', '6', '40', 'xtc_cfg_pull_down_order_statuses(', 'xtc_get_order_status_name', now())");
    xtc_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_key, configuration_value, configuration_group_id, sort_order, set_function, date_added)" .
      "  values ('MODULE_PAYMENT_" . strtoupper($this->code) . "_DELETE_ORDER', 'True', '6', '0', 'xtc_cfg_select_option(array(\'True\', \'False\'), ', now())");
    xtc_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_key, configuration_value, configuration_group_id, sort_order, date_added)" .
      "  values ('MODULE_PAYMENT_" . strtoupper($this->code) . "_PURPOSE', 'Best. {ORDERID}, {SHOPNAME}', '6', '10', now())");

    if ($this->code == 'gc_creditcard') {
      xtc_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_key, configuration_value, configuration_group_id, sort_order, set_function, date_added)" .
        "  values ('MODULE_PAYMENT_" . strtoupper($this->code) . "_VISAMASTER', 'True', '6', '0', 'xtc_cfg_select_option(array(\'True\', \'False\'), ', now())");
      xtc_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_key, configuration_value, configuration_group_id, sort_order, set_function, date_added)" .
        "  values ('MODULE_PAYMENT_" . strtoupper($this->code) . "_AMEX', 'True', '6', '0', 'xtc_cfg_select_option(array(\'True\', \'False\'), ', now())");
      xtc_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_key, configuration_value, configuration_group_id, sort_order, set_function, date_added)" .
        "  values ('MODULE_PAYMENT_" . strtoupper($this->code) . "_JCB', 'True', '6', '0', 'xtc_cfg_select_option(array(\'True\', \'False\'), ', now())");
    }


    //create table to register orders and status.
    xtc_db_query("CREATE TABLE IF NOT EXISTS gc_transactions(
                  tx_id int(11) NOT NULL AUTO_INCREMENT,
                  order_id int(11) NOT NULL,
                  rc int(11) NULL,
                  rc_msg varchar(255) NULL,
                  init_start int(11) NULL,
                  init_end int(11) NULL,
                  time_finished int(11) NULL,
                  reference varchar(255) NULL,
                  backend_tx_id varchar(255) NULL,
                  result_payment int(11) NULL,
                  result_payment_msg varchar(255) NULL,
                  tx_status int(1) NOT NULL,
                  payment_code varchar(100) NULL,
                  comment text NULL,
                  PRIMARY KEY (tx_id)
                  )");

    $columns_query = xtc_db_query("SHOW COLUMNS FROM `gc_transactions` LIKE '%payment_code%'");
    if (!xtc_db_num_rows($columns_query)) {
      xtc_db_query("ALTER TABLE `gc_transactions` ADD `payment_code` varchar(100) NULL");
    }

    $columns_query = xtc_db_query("SHOW COLUMNS FROM `gc_transactions` LIKE '%comment%'");
    if (!xtc_db_num_rows($columns_query)) {
      xtc_db_query("ALTER TABLE `gc_transactions` ADD `comment` text NULL");
    }
  }

// end install()

  /**
   * Remove the module (Administration Tool)_
   * TABLES: configuration
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return void
   */
  function remove() {
    $strKeys = implode("', '", $this->keys());
    xtc_db_query("delete from " . TABLE_CONFIGURATION . " where configuration_key in ('" . $strKeys . "')");
  }

// end remove()

  /**
   * Retrieve the modules configuration keys (Administration Tool)_
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return array
   */
  function keys() {
    $keys = array("MODULE_PAYMENT_" . strtoupper($this->code) . "_STATUS");
    $keys[] = "MODULE_PAYMENT_" . strtoupper($this->code) . "_SORT_ORDER";
    $keys[] = "MODULE_PAYMENT_" . strtoupper($this->code) . "_MERCHANTID";
    $keys[] = "MODULE_PAYMENT_" . strtoupper($this->code) . "_PROJECTID";
    $keys[] = "MODULE_PAYMENT_" . strtoupper($this->code) . "_PASSWORD";
    $keys[] = "MODULE_PAYMENT_" . strtoupper($this->code) . "_ZONE";
    $keys[] = "MODULE_PAYMENT_" . strtoupper($this->code) . "_ALLOWED";
    $keys[] = "MODULE_PAYMENT_" . strtoupper($this->code) . "_DELETE_ORDER";
    $keys[] = "MODULE_PAYMENT_" . strtoupper($this->code) . "_ORDER_STATUS_ID_ERROR";
    $keys[] = "MODULE_PAYMENT_" . strtoupper($this->code) . "_ORDER_STATUS_ID_OK";
    $keys[] = "MODULE_PAYMENT_" . strtoupper($this->code) . "_ORDER_STATUS_ID_TEMP";
    $keys[] = "MODULE_PAYMENT_" . strtoupper($this->code) . "_PURPOSE";

    if ($this->code == 'gc_creditcard') {
      $keys[] = "MODULE_PAYMENT_" . strtoupper($this->code) . "_VISAMASTER";
      $keys[] = "MODULE_PAYMENT_" . strtoupper($this->code) . "_AMEX";
      $keys[] = "MODULE_PAYMENT_" . strtoupper($this->code) . "_JCB";
    }

    return $keys;
  }

// end keys()

  /**
   * Get Source parameter.
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return String
   */
  public function getGcSource() {
    if (defined('DIR_ADMIN') && file_exists(DIR_ADMIN . 'includes/version.php')) {
      include_once(DIR_ADMIN . 'includes/version.php');
      $this->shopVersion = PROJECT_MAJOR_VERSION . "." . PROJECT_MINOR_VERSION;
    }
    else {
      $this->shopVersion = "1.06";
    }

    return "xtc Modified eCommerce " . $this->shopVersion . ";xtc Modified Plugin " . __GIROCONNECT_PLUGIN_VERSION__;
  }

  /**
   * Get the payment purpose.
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return string The purpose
   */
  public function getPurpose() {
    $strPurpose = giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_PURPOSE');
    $strLastName = "";
    $strFirstName = "";
    $strShopName = "";

    $iCustomerNr = $_SESSION['customer_id'];
    $strLastName = $_SESSION['customer_last_name'];
    $strFirstName = $_SESSION['customer_first_name'];
    $strName = $_SESSION['customer_first_name'] . ", " . $_SESSION['customer_last_name'];

    $strShopName = STORE_NAME;

    $strPurpose = str_replace("{ORDERID}", $_SESSION['tmp_oID'], $strPurpose);
    $strPurpose = str_replace("{CUSTOMERID}", $iCustomerNr, $strPurpose);
    $strPurpose = str_replace("{SHOPNAME}", $strShopName, $strPurpose);
    $strPurpose = str_replace("{CUSTOMERNAME}", $strName, $strPurpose);
    $strPurpose = str_replace("{CUSTOMERFIRSTNAME}", $strFirstName, $strPurpose);
    $strPurpose = str_replace("{CUSTOMERLASTNAME}", $strLastName, $strPurpose);

    return utf8_encode(trim(substr($strPurpose, 0, 27)));
  }

  /**
   * Get the extended logo for creditcards.
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return string
   */
  public function getExtendedLogo() {
    $visa_msc = giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_VISAMASTER');
    $amex = giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_AMEX');
    $jcb = giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_JCB');

    if (strtoupper($visa_msc) == 'TRUE') {
      $bvisa_msc = true;
    }
    else {
      $bvisa_msc = false;
    }

    if (strtoupper($amex) == 'TRUE') {
      $bamex = true;
    }
    else {
      $bamex = false;
    }

    if (strtoupper($jcb) == 'TRUE') {
      $bjcb = true;
    }
    else {
      $bjcb = false;
    }

    if (!$bvisa_msc && !$bamex && !$bjcb) {
      $bvisa_msc = true;
    }

    return GiroCheckout_SDK_Tools::getCreditCardLogoName($bvisa_msc, $bamex, $bjcb);
  }

// End getGcSource()

  public function encodeText($p_strText)
  {
    //return mb_convert_encoding($p_strText, "UTF-8", mb_detect_encoding($p_strText, "UTF-8, ISO-8859-1, ISO-8859-15", true));
    if( strtoupper($_SESSION['language_charset']) != "UTF-8" ) {
      return utf8_encode($p_strText);
    }
    else {
      return $p_strText;
    }
  }

  /**
   * Get the payment purpose for giropay payment.
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return string The purpose
   */
  public function getGiropayPurpose() {
    $strPurpose = giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_PURPOSE');
    $strLastName = "";
    $strFirstName = "";
    $strShopName = "";

    $iCustomerNr = $_SESSION['customer_id'];
    $strLastName = $_SESSION['customer_last_name'];
    $strFirstName = $_SESSION['customer_first_name'];
    $strName = $_SESSION['customer_first_name'] . ", " . $_SESSION['customer_last_name'];

    $strShopName = STORE_NAME;

    $strPurpose = str_replace("{ORDERID}", $_SESSION['tmp_oID'], $strPurpose);
    $strPurpose = str_replace("{CUSTOMERID}", $iCustomerNr, $strPurpose);
    $strPurpose = str_replace("{SHOPNAME}", $strShopName, $strPurpose);
    $strPurpose = str_replace("{CUSTOMERNAME}", $strName, $strPurpose);
    $strPurpose = str_replace("{CUSTOMERFIRSTNAME}", $strFirstName, $strPurpose);
    $strPurpose = str_replace("{CUSTOMERLASTNAME}", $strLastName, $strPurpose);

    $bValidPurpose = self::validateGiropayPurpose($strPurpose);

    if (!$bValidPurpose) {
      $strPurposeFormat = preg_replace("([^[A-Za-z0-9\+\?\-\:\(\)\.\,\'\/])", '', $strPurpose);
    } else {
      $strPurposeFormat = $strPurpose;
    }

    $strPurposeFormat = substr($strPurposeFormat, 0, 27);

    return utf8_encode(trim($strPurposeFormat));
  }

  /**
   * Validate the payment purpose for giropay payment.
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2022, S-Public Services GmbH
   * @return array
   */
  public function validateGiropayPurpose($purpose) {
    $strPurpose = $purpose;

    if (!empty($strPurpose)) {
      if (preg_match("/^[A-Za-z0-9\+\?\-\:\(\)\.\,\'\/\s]+$/", $strPurpose)) {
        return true;
      }
      else {
        return false;
      }
    }

    return true;
  }
}

// end class giroconnect_main