<?php

/**
 * Payment Modul für s-publicservices.de Giropay.
 *
 * @version   4.1.8
 * @author    Thorsten Marx <thorsten.marx@s-publicservices.de>
 * @copyright 2011-2015 S-Public Services GmbH
 * @link      http://www.s-publicservices.de
 * @link      http://www.xtc-modified.org
 * @license   http://opensource.org/licenses/gpl-2.0.php GNU Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */
// Lib laden.
if (file_exists(DIR_FS_CATALOG . 'includes/classes/giroconnect/class.giroconnect.php')) {
  include_once DIR_FS_CATALOG . 'includes/classes/giroconnect/class.giroconnect.php';
} else {
  include_once '../includes/classes/giroconnect/class.giroconnect.php';
}

if (file_exists(DIR_FS_CATALOG . 'includes/classes/giroconnect/library/GiroCheckout_SDK/GiroCheckout_SDK.php') === true) {
  include_once DIR_FS_CATALOG . 'includes/classes/giroconnect/library/GiroCheckout_SDK/GiroCheckout_SDK.php';
} else {
  include_once '../includes/classes/giroconnect/library/GiroCheckout_SDK/GiroCheckout_SDK.php';
}

/**
 * Class to manage a giropay payment method.
 *
 * Extends the giroconnect_main
 *
 * @author S-Public Services GmbH
 * @package GiroCheckout
 * @copyright Copyright (c) 2014, S-Public Services GmbH
 */
class gc_giropay extends giroconnect_main {

  const CART_TYPE_PHYSICAL = "PHYSICAL";
  const CART_TYPE_DIGITAL = "DIGITAL";
  const CART_TYPE_MIXED = "MIXED";

  /**
   * Constructor method.
   * Set the payment type and payment method credentials.
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return void
   */
  function __construct() {
    global $order;

    $this->_setCode("gc_giropay");
    $this->_setLang();

    $this->title = giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_TEXT_TITLE');
    $this->description = giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_TEXT_DESCRIPTION');
    $this->description_checkout = xtc_image('includes/classes/giroconnect/library/logos/Logo_giropay_50_px.jpg', '', '', '', 'style="display: block;"') . giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_TEXT_DESCRIPTION');

    if (defined('MODULE_PAYMENT_' . strtoupper($this->code) . '_STATUS')) {
      $this->sort_order = giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_SORT_ORDER');
      $this->enabled = ((giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_STATUS') == 'True') ? true : false);
      $this->redirect = true;
      $this->tmpOrders = true;
      $this->form_action_url = true;
      $this->tmpStatus = giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_ORDER_STATUS_ID_TEMP');
    }

    if (is_object($order)) {
      $this->update_status();
    }
  }

  //end gc_giropay()

  /**
   * Set array with the title, description and fields to display.
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return array
   */
  function selection() {

    $pic = xtc_image('includes/classes/giroconnect/library/logos/Logo_giropay_50_px.jpg', '', '', '', 'style="display: block;"');
    $desc = $pic . $this->description;

    global $_POST;

    return array(
        'id' => $this->code,
        'module' => $this->title,
        'description' => $desc
    );
  }

  //end selection()

  /**
   * Valid the payment datas inserted by the user.
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return boolean
   */
  function pre_confirmation_check() {

    global $_POST;

    return true;
  }

  //end pre_confirmation_check()

  /**
   * Functions to do when the button is pressed.
   * Set hidden fields with payment datas.
   * Get the total.
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return void
   */
  function process_button() {

    global $order, $_POST, $xtPrice;

    if ($_SESSION['customers_status']['customers_status_show_price_tax'] == 0 && $_SESSION['customers_status']['customers_status_add_tax_ot'] == 1) {
      $total = $order->info['total'] + $order->info['tax'];
    } else {
      $total = $order->info['total'];
    }

    //sores total because of bug due to wrong pricing after an aborted transaction
    $_SESSION['giroconnect']['total'] = round($xtPrice->xtcCalculateCurrEx($total, $order->info['currency']), $xtPrice->get_decimal_places($order->info['currency']));

    return '<script type="text/javascript">
$(document).ready(function()
    {
$("#checkout_confirmation").find("input[type=image]").click(function(){

        document.getElementById("checkout_confirmation").submit();
	$(this).attr( "disabled", "true" );
});
});
</script>';
  }

//end process_button()

  /**
   * Initialize the payment
   *
   * @author S-Public Services GmbH
   * @package GiroCheckout
   * @copyright Copyright (c) 2014, S-Public Services GmbH
   * @return boolean
   */
  function payment_action() {
  global $_POST, $order;
    $order_id = $_SESSION['tmp_oID'];

    // Fix for XTC Bug
    //
    // $order->info['total'] is in 'after_process' String with currency ->
    // 1.02 EUR
    // so it has to be set here
    $amount = $_SESSION['giroconnect']['total'];
    $currency = $_SESSION['currency'];


    $transaction_id = $order_id;
    $vwz = $this->getGiropayPurpose();
    $merchantId = giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_MERCHANTID');
    $projectId = giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_PROJECTID');
    $password = giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_PASSWORD');
    $urlRedirect = str_replace('&amp;', '&', xtc_href_link('callback/giroconnect/gc_redirect.php', '', 'SSL')) . '?pm=' . $this->code;
    $urlNotify = str_replace('&amp;', '&', xtc_href_link('callback/giroconnect/gc_notify.php', '', 'SSL')) . '?pm=' . $this->code;
    $sourceId = $this->getGcSource();
    $initSuccess = true;
    $delete_order = ((giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_DELETE_ORDER') == 'True') ? true : false);
    

    //Insert new giroconnect transaction with init status.
    //xtc_db_query('delete from gc_transactions where order_id = "' . xtc_db_input((int) $transaction_id) . '"');
    $sql_data_array = array(
        'order_id' => $transaction_id,
        'rc' => 'null',
        'rc_msg' => 'null',
        'init_start' => strtotime("now"),
        'init_end' => 'null',
        'time_finished' => 'null',
        'reference' => 'null',
        'backend_tx_id' => 'null',
        'result_payment' => 'null',
        'tx_status' => 0,
        'payment_code' => $this->code,
        'comment' => $vwz,
    );

    xtc_db_perform('gc_transactions', $sql_data_array);
    $gc_tx_id = xtc_db_insert_id();

    try {
      $iNumProdVirtual = 0;
      $iNumProdPhysical = 0;
      $strCartType = self::CART_TYPE_PHYSICAL;
      $oCart = new GiroCheckout_SDK_Request_Cart();

      foreach ($order->products as $aProduct) {
        $oCart->addItem( $this->encodeText($aProduct["name"]), $aProduct["qty"], $aProduct["price"]*100, $aProduct["model"] );
        error_log("aProduct:".print_r($aProduct, true));
      }

      $aAddress = array();

      if (isset($order->delivery)) {
        $aAddress = $order->delivery;
      } else {
        if (isset($order->customer)) {
          $aAddress = $order->customer;
        }
      }
      error_log("Purpose:$vwz");

      $request = new GiroCheckout_SDK_Request('giropayTransaction');
      $request->setSecret($password);
      $request->addParam('merchantId', $merchantId)
              ->addParam('projectId', $projectId)
              ->addParam('merchantTxId', $gc_tx_id)
              ->addParam('amount', $amount * 100)
              ->addParam('currency', $currency)
              ->addParam('purpose', $vwz)
              ->addParam('urlRedirect', $urlRedirect)
              ->addParam('urlNotify', $urlNotify)
              ->addParam('sourceId', $sourceId)
              ->addParam('orderId', $transaction_id)
              ->addParam('customerId', $_SESSION["customer_id"])
              ->addParam('shippingAddresseFirstName', $this->encodeText($aAddress["firstname"]))
              ->addParam('shippingAddresseLastName', $this->encodeText($aAddress["lastname"]))
              ->addParam('shippingCompany', $this->encodeText($aAddress["company"]))
              ->addParam('shippingAdditionalAddressInformation', $aAddress[""])
              ->addParam('shippingStreet',$this->encodeText( $aAddress["street_address"]))
              ->addParam('shippingZipCode', $aAddress["postcode"])
              ->addParam('shippingCity', $this->encodeText($aAddress["city"]))
              ->addParam('shippingCountry', $aAddress["country"]["iso_code_2"])
              ->addParam('shippingEmail', $order->country["email_address"])
              ->addParam('cart', $oCart)
              ->addParam('shoppingCartType', $strCartType)
              ->submit();

      if (!$request->requestHasSucceeded()) {
        $iReturnCode = $request->getResponseParam('rc');
        $strResponseMsg = $request->getResponseMessage($iReturnCode, strtoupper($this->language));
        $initSuccess = false;
        $newStatus = giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_ORDER_STATUS_ID_ERROR');
      } else {
        $iReturnCode = $request->getResponseParam('rc');
        $strResponseMsg = $request->getResponseMessage($iReturnCode, strtoupper($this->language));
        $strReference = $request->getResponseParam('reference');
        $strUrlRedirect = $request->getResponseParam('redirect');
        $newStatus = giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_ORDER_STATUS_ID_TEMP');

        //Change giroconnect transaction to pending status.
        xtc_db_query("update gc_transactions set init_end = " . strtotime("now") . ", rc = " . xtc_db_input($iReturnCode) . ", reference = '" . xtc_db_input($strReference) . "', rc_msg = '" . xtc_db_input($strResponseMsg) . "', tx_status = 1 where tx_id = '" . xtc_db_input($gc_tx_id) . "'");
      }
    } catch (Exception $e) {
      $strResponseMsg = GiroCheckout_SDK_ResponseCode_helper::getMessage(5100, strtoupper($this->language));
      $iReturnCode = 5100;
      $initSuccess = false;
      $newStatus = giroconnect_main::constant('MODULE_PAYMENT_' . strtoupper($this->code) . '_ORDER_STATUS_ID_ERROR');
      error_log("ERROR:".$e->getMessage());
    }

    if (!$initSuccess) {

      //Change giroconnect transaction to failed status.
      xtc_db_query("update gc_transactions set init_end = " . strtotime("now") . ", rc = " . xtc_db_input($iReturnCode) . ", rc_msg = '" . xtc_db_input($strResponseMsg) . "', tx_status = 3 where tx_id = '" . xtc_db_input($gc_tx_id) . "'");

      // Eintrag zur Historie der Bestellung hinzuf�gen.
      $sql_data_array = array(
          'orders_id' => (int) $transaction_id,
          'orders_status_id' => $newStatus,
          'date_added' => 'now()',
          'customer_notified' => 0,
          'comments' => 'init '. $this->code .' payment error: '. $strResponseMsg
      );
      xtc_db_perform(TABLE_ORDERS_STATUS_HISTORY, $sql_data_array);

      // Bestell-Status in Tabelle orders updaten.
      xtc_db_query("update " . TABLE_ORDERS . " set orders_status = '" . xtc_db_input($newStatus) . "', last_modified = now() where orders_id = '" . xtc_db_input((int) $transaction_id) . "' AND payment_class = '" . xtc_db_input($this->code) . "'");

      if ($delete_order) {
        $check_query = xtc_db_query('select orders_id from ' . TABLE_ORDERS . ' where orders_id = "' . xtc_db_input((int) $transaction_id) . '" limit 1');
        if (xtc_db_num_rows($check_query) > 0) {
          xtc_db_query('delete from ' . TABLE_ORDERS . ' where orders_id = "' . xtc_db_input((int) $transaction_id) . '"');
          xtc_db_query('delete from ' . TABLE_ORDERS_TOTAL . ' where orders_id = "' . xtc_db_input((int) $transaction_id) . '"');
          xtc_db_query('delete from ' . TABLE_ORDERS_STATUS_HISTORY . ' where orders_id = "' . xtc_db_input((int) $transaction_id) . '"');
          xtc_db_query('delete from ' . TABLE_ORDERS_PRODUCTS . ' where orders_id = "' . xtc_db_input((int) $transaction_id) . '"');
          xtc_db_query('delete from ' . TABLE_ORDERS_PRODUCTS_ATTRIBUTES . ' where orders_id = "' . xtc_db_input((int) $transaction_id) . '"');
          xtc_db_query('delete from ' . TABLE_ORDERS_PRODUCTS_DOWNLOAD . ' where orders_id = "' . xtc_db_input((int) $transaction_id) . '"');
        }
        unset($_SESSION['cart_GC_ID']);
      }

      xtc_redirect(str_replace('&amp;', '&', xtc_href_link(FILENAME_CHECKOUT_PAYMENT, 'payment_error=' . $this->code . '&error=' . urlencode($strResponseMsg), 'SSL', true, false)));
      return;
    }else {
      // Eintrag zur Historie der Bestellung hinzuf�gen.
      $sql_data_array = array(
          'orders_id' => (int) $transaction_id,
          'orders_status_id' => $newStatus,
          'date_added' => 'now()',
          'customer_notified' => 0,
          'comments' => 'payment with '. $this->code . ' initialized'
      );
      xtc_db_perform(TABLE_ORDERS_STATUS_HISTORY, $sql_data_array);
      
      xtc_redirect($strUrlRedirect);
    }

    return true;
  }

  //end payment_action()
}

?>